===============
Database models
===============

Click below to explore Bodhi's database models:

.. autosummary::
   :toctree: docblocks

   bodhi.server.models


Database Schema
===============

The Bodhi database schema can be seen below.

.. figure:: ../images/database.png
   :align:  center

   Database schema.
